==> nextcloud-27.1.11.tgz: nextcloud/apps/twofactor_totp/l10n/cs.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Pro svůj účet jste povolil(a) dvoufázové ověření pomocí TOTP",
    "You disabled TOTP two-factor authentication for your account" : "Pro váš účet jste zakázali dvoufázové ověřování pomocí TOTP",
    "TOTP two-factor authentication disabled by an admin" : "TOTP dvoufázové přihlašování vypnuto správcem",
    "TOTP (Authenticator app)" : "TOTP (aplikace pro ověřování se)",
    "Authenticate with a TOTP app" : "Přihlaste se pomocí TOTP aplikace",
    "Two-Factor TOTP Provider" : "Poskytovatel TOTP kódů pro dvoufázové ověření",
    "TOTP two-factor provider" : "Poskytovatel dvoufázového TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Poskytovatel dvouúřovňového ověřování pro TOTP (dle normy RFC 6238)",
    "Enable TOTP" : "Zapnout TOTP",
    "Could not enable TOTP" : "TOTP se nepodařilo zapnout",
    "Could not verify your key. Please try again" : "Ověření vašeho klíče se nezdařilo. Zkuste to znovu.",
    "Your new TOTP secret is:" : "Vaše nové TOTP tajemství je:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pro rychlé nastavení naskenujte tento QR kód svou TOTP aplikací:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Po dokončení nastavení aplikace se zadáním zkušebního kódu níže ujistěte, že vše správně funguje:",
    "Authentication code" : "Ověřovací kód",
    "Verify" : "Ověřit",
    "Get the authentication code from the two-factor authentication app on your device." : "Získat ověřovací kód z aplikace na vašem přístroji.",
    "Submit" : "Odeslat"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/cs.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Pro svůj účet jste povolil(a) dvoufázové ověření pomocí TOTP",
    "You disabled TOTP two-factor authentication for your account" : "Pro váš účet jste zakázali dvoufázové ověřování pomocí TOTP",
    "TOTP two-factor authentication disabled by the administration" : "TOTP dvoufázové přihlašování vypnuto správci",
    "TOTP (Authenticator app)" : "TOTP (aplikace pro ověřování se)",
    "Authenticate with a TOTP app" : "Přihlaste se pomocí TOTP aplikace",
    "Two-Factor TOTP Provider" : "Poskytovatel TOTP kódů pro dvoufázové ověření",
    "Two-factor TOTP provider" : "Poskytovatel TOTP kódů pro dvoufázové ověření",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Poskytovatel dvouúřovňového ověřování pro TOTP (dle normy RFC 6238)",
    "Enable TOTP" : "Zapnout TOTP",
    "Could not enable TOTP" : "TOTP se nepodařilo zapnout",
    "Could not verify your key. Please try again" : "Ověření vašeho klíče se nezdařilo. Zkuste to znovu.",
    "Your new TOTP secret is:" : "Vaše nové TOTP tajemství je:",
    "For quick setup, scan this QR code with your TOTP app:" : "Pro rychlé nastavení naskenujte tento QR kód svou TOTP aplikací:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Po dokončení nastavení aplikace se zadáním zkušebního kódu níže ujistěte, že vše správně funguje:",
    "Authentication code" : "Ověřovací kód",
    "Verify" : "Ověřit",
    "Get the authentication code from the two-factor authentication app on your device." : "Získat ověřovací kód z aplikace na vašem přístroji.",
    "Submit" : "Odeslat",
    "TOTP two-factor authentication disabled by an admin" : "TOTP dvoufázové přihlašování vypnuto správcem",
    "TOTP two-factor provider" : "Poskytovatel dvoufázového TOTP",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Poskytovatel dvouúřovňového ověřování pro TOTP (dle normy RFC 6238)"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
